@@ -4,7 +4,7 @@
 import pytest
 
 from webhooks.exceptions import SenderNotCallable
-from webhooks import webhook, unhashed_hook
+from webhooks import webhook
 
 
 def test_callable_sender():
@@ -15,4 +15,3 @@ def test_callable_sender():
 
     with pytest.raises(SenderNotCallable):
         basic(creator='pydanny')
-
